var a00815 =
[
    [ "PatchMap", "a00977.html", "a00977" ],
    [ "Child", "a00985.html", "a00985" ]
];